<?php

/**
 *  Default Theme options
 *
 * @since words 1.0.0
 *
 * @param null
 * @return array $words_theme_layout
 *
 */
if ( !function_exists('words_default_theme_options') ) :
    function words_default_theme_options() {

        $default_theme_options = array(
            /*feature section options*/
            'words-footer-copyright'=>'',            
        );

        return apply_filters( 'words_default_theme_options', $default_theme_options );
    }
endif;


/**
 *  Get theme options
 *
 * @since words 1.0.0
 *
 * @param null
 * @return array words_theme_options
 *
 */
if ( !function_exists('words_get_theme_options') ) :
    function words_get_theme_options() {

        $words_default_theme_options = words_default_theme_options();
        

        $words_get_theme_options = get_theme_mod( 'words_theme_options');
        if( is_array( $words_get_theme_options )){
            return array_merge( $words_default_theme_options, $words_get_theme_options );
        }
        else{
            return $words_default_theme_options;
        }

    }
endif;

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function words_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	/*adding sections for footer options*/
    $wp_customize->add_section( 'words-footer-option', array(
        'priority'       => 170,
        'capability'     => 'edit_theme_options',
        'theme_supports' => '',
        'title'          => __( 'Copyright Text', 'words' )
    ) );

    /*copyright*/
    $wp_customize->add_setting( 'words_theme_options[words-footer-copyright]', array(
        'capability'        => 'edit_theme_options',
        'default'           => __('All Right Reserved 2016', 'words'),
        'sanitize_callback' => 'wp_kses_post'
    ) );
    $wp_customize->add_control( 'words-footer-copyright', array(
        'label'     => __( 'Copyright Text', 'words' ),
        'description' => __('Your Own Copyright Text', 'words'),
        'section'   => 'words-footer-option',
        'settings'  => 'words_theme_options[words-footer-copyright]',
        'type'      => 'text',
        'priority'  => 10
    ) );   
}
add_action( 'customize_register', 'words_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function words_customize_preview_js() {
	wp_enqueue_script( 'words_customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151216', true );
}
add_action( 'customize_preview_init', 'words_customize_preview_js' );
